'use strict';

var spawn = require('cross-spawn');
var scriptsPath = require.resolve('./scripts');
var reactHot = require('./reactHot');

var _require = require('./config'),
    resolvePaths = _require.resolvePaths,
    write = _require.write;

/**
 * Run the given script
 *
 */


function run(script) {
  var params = [scriptsPath].concat(' ' + script);
  var config = { stdio: 'inherit' };
  var result = spawn.sync('node', params, config);
  process.exit(result.status);
}

/**
 * Write the config file and run a script ('serve', 'build', 'test')
 * @param {Object} config
 * @param {String} script - some like 'serve', 'build', 'test'
 * @return {Promise}
 */
function prepareAndRun(config, script) {
  // Resolve config paths
  resolvePaths(config, config.rootPath);

  // Enable cache by default
  if (config.cache !== false) {
    config.cache = true;
  }

  // Create the react hot loader entry point if it is enabled
  return reactHot.apply(config)
  // Write config file
  .then(function () {
    return write(config);
  })
  // Run the script
  .then(function () {
    return run(script);
  }).catch(function (err) {
    return console.log(err);
  });
}

module.exports = {
  prepareAndRun: prepareAndRun
};