'use strict';

var fs = require('fs');
var chokidar = require('chokidar');
var express = require('express');
var webpack = require('webpack');
var WebpackDevServer = require('webpack-dev-server');

var Logger = require('../util/logger');
var updateSchema = require('../util/updateSchema');
var config = require('../config.tmp.json');
var webPackDevConfig = require('../webpack/webpack.prod.config.js');

Logger.setDebug(config.debug);

/**
 *
 *
 */
function build() {
  return prepareSchema().then(runBuild);
}

/**
 *
 *
 */
function prepareSchema() {
  if (!config.schema || !config.schema.entry) {
    Logger.debug('No schema found.');
    return Promise.resolve();
  }

  return updateSchema();
}

/**
 *
 *
 */
function runBuild() {
  var start = Date.now();
  var compiler = webpack(webPackDevConfig);

  compiler.run(function (err, stat) {
    var filelName = config.filename || 'bundle.js';
    Logger.info('');
    var time = (Date.now() - start) / 1000;
    Logger.info('Build process finished in ' + time + ' seconds.');
  });
}

module.exports = build;