'use strict';

var fs = require('fs');
var chokidar = require('chokidar');
var express = require('express');
var webpack = require('webpack');
var WebpackDevServer = require('webpack-dev-server');

var Logger = require('../util/logger');
var updateSchema = require('../util/updateSchema');
var config = require('../config.tmp.json');
var webPackDevConfig = require('../webpack/webpack.dev.config.js');

Logger.setDebug(config.debug);

/**
 *
 *
 */
function serve() {
  return prepareSchema().then(createDevServer);
}

/**
 *
 *
 */
function prepareSchema() {
  if (!config.schema || !config.schema.entry) {
    Logger.debug('No schema found.');
    return Promise.resolve();
  }

  Logger.debug('Prepare graphql schema.');

  watchSchema();

  return updateSchema();
}

/**
 *
 *
 */
function watchSchema() {
  if (!config.schema.watch) {
    return;
  }

  var shouldSkip = /schema\.(json|graphql)/;

  Logger.debug("Watch for schema changes at: ", config.schema.watch);

  var watcher = chokidar.watch(config.schema.watch, {
    ignored: /[\/\\]\./,
    persistent: true
  });

  var update = function update(path) {
    if (shouldSkip.test(path)) {
      return;
    }
    updateSchema().then(function () {
      Logger.debug('Schema successfull udpated.');
    });
  };

  watcher.on('change', update);
}

/**
 *
 *
 */
function createDevServer() {
  var compiler = webpack(webPackDevConfig);

  var app = new WebpackDevServer(compiler, {
    publicPath: config.publicPath,
    hot: true,
    historyApiFallback: true,
    stats: {
      colors: true,
      assets: false,
      chunks: false
    },
    proxy: config.proxy
  });

  Logger.info("Running webpack...");

  compiler.plugin('done', function () {
    Logger.info('--> App is ready and running on http://localhost:' + config.port + ' <--');
  });

  // Serve static resources
  app.use('/', express.static(config.staticsPath));
  app.listen(config.port);
}

module.exports = serve;